import importlib.util
import setuptools
import shlex
import subprocess
import sys

def run(setup_path, pip_arguments="", remove_self=False, pip=[sys.executable, "-m", "pip"], extras=[]):
	pip_arguments = shlex.split(pip_arguments)
	def setuptools_setup(install_requires=[], extras_require={}, *args, **kwargs):
		requirements = []
		requirements += install_requires
		for extra in extras:
			if extra not in extras_require:
				raise SystemExit("No extra \"%s\" is known." % extra)
			requirements += extras_require[extra]
		subprocess.check_call(pip + ["install"] + requirements)
	setuptools.setup = setuptools_setup

	spec = importlib.util.spec_from_file_location("__main__", str(setup_path))
	setup = importlib.util.module_from_spec(spec)
	spec.loader.exec_module(setup)

	if remove_self:
		subprocess.check_call(pip + ["uninstall", "--yes", "setuper"])



import argparse

import setuper

def main():
	argument_parser = argparse.ArgumentParser(description="Install the requirements of a setuptools setup.py file.")
	argument_parser.add_argument("setup_path", help="The path to setup.py.")
	argument_parser.add_argument("--pip-arguments", help="Extra arguments to pass to Pip.")
	argument_parser.add_argument("--remove-self", action="store_true", help="Remove setuper after installing requirements.")
	argument_parser.add_argument("--extras", help="Comma separated categories of extras_require extras to install.")
	arguments = argument_parser.parse_args()

	setuper.run(arguments.setup_path, pip_arguments=arguments.pip_arguments, remove_self=arguments.remove_self, extras=arguments.extras.split(","))

if __name__ == "__main__":
	main()



#!/usr/bin/env python3
import sys

import setuptools

def main():
	if sys.version_info[:2] < (3, 5):
		raise SystemExit("setuper requires at least Python 3.5.")
	setuptools.setup(
		name="setuper",
		version="0.0.7",
		description="A Python module for installing the dependencies listed in a setuptools setup.py file.",
		url="https://github.com/chrisgavin/setuper/",
		packages=["setuper"],
		python_requires=">=3.5",
		classifiers=[
			"Programming Language :: Python :: 3",
			"Programming Language :: Python :: 3.5",
			"Programming Language :: Python :: 3.6",
			"Programming Language :: Python :: 3.7",
			"Programming Language :: Python :: 3.8",
			"Programming Language :: Python :: 3 :: Only",
		],
		entry_points={
			"console_scripts":[
				"setuper = setuper.__main__:main",
			],
		},
		extras_require={
			"dev": [
				"pytest",
				"virtualenv",
			],
		},
	)

if __name__ == "__main__":
	main()
